@@ -15,12 +15,11 @@ AWSCLI
 ----
 A Universal Command Line Environment for Amazon Web Services.
 """
-
-import importlib.abc
 import os
+import importlib.abc
 import sys
 
-__version__ = '2.28.25'
+__version__ = '2.9.9'
 
 #
 # Get our data path to be added to botocore's search path
@@ -37,18 +36,10 @@ _awscli_data_path.append(
 os.environ['AWS_DATA_PATH'] = os.pathsep.join(_awscli_data_path)
 
 
-SCALAR_TYPES = set(
-    [
-        'string',
-        'float',
-        'integer',
-        'long',
-        'boolean',
-        'double',
-        'blob',
-        'timestamp',
-    ]
-)
+SCALAR_TYPES = set([
+    'string', 'float', 'integer', 'long', 'boolean', 'double',
+    'blob', 'timestamp'
+])
 COMPLEX_TYPES = set(['structure', 'map', 'list'])
 
 
@@ -66,14 +57,13 @@ class TopLevelImportAliasFinder(importlib.abc.MetaPathFinder):
     Note: That this import alias only comes into affect if anything is
     imported from the awscli package.
     """
-
     _PACKAGES = [
         'botocore',
         's3transfer',
     ]
     _TARGET_FINDERS = [
-        'pyimod02_importers.PyiFrozenImporter',  # Pyinstaller injected finder
-        '_frozen_importlib_external.PathFinder',  # Built-in path finder
+        'pyimod02_importers.FrozenImporter',  # Pyinstaller injected finder
+        '_frozen_importlib_external.PathFinder'  # Built-in path finder
     ]
 
     def __init__(self, underlying_finder):
@@ -94,7 +84,7 @@ class TopLevelImportAliasFinder(importlib.abc.MetaPathFinder):
                 finder_name = finder.__class__.__name__
             full_cls_name = f'{finder.__module__}.{finder_name}'
             if full_cls_name in cls._TARGET_FINDERS:
-                meta_path.insert(i, cls(finder))
+                meta_path[i] = cls(finder)
                 return
 
     def find_spec(self, fullname, path, target=None):
